@@ -431,13 +431,21 @@ class NaPoleonXConnector(object):
 
     """
 
-    url_auth = 'https://api.napoleonx.ai/auth-service/oauth/token'
-    url = 'https://api.napoleonx.ai/quote-service/v1/eod-quote/filter'
-    signal_url = 'https://api.napoleonx.ai/signal-service/v1/signal-computation/filter'
-    url_product = 'https://api.napoleonx.ai/product-service/v1/product/'
+#    url_auth = 'https://api.napoleonx.ai/auth-service/oauth/token'
+#    url = 'https://api.napoleonx.ai/quote-service/v1/eod-quote/filter'
+#    signal_url = 'https://api.napoleonx.ai/signal-service/v1/signal-computation/filter'
+#    url_product = 'https://api.napoleonx.ai/product-service/v1/product/'
+
+#    url_auth = 'http://15.237.36.185:9000/auth-service/oauth/token'
+    url_auth = 'http://15.237.36.185:9000/oauth/token'
+    url = 'http://15.237.36.185:9000/v1/quote-service/filter'
+    signal_url = 'http://15.237.36.185:9000/v1/position-service/filter'
+    url_product = 'http://15.237.36.185:9000/v1/product-service/'
+
     data = {
         'grant_type': 'password',
-        'scope': 'read write'
+#        'scope': 'read write',
+        'scope': 'read'
     }
 
     headers = {
@@ -481,7 +489,8 @@ class NaPoleonXConnector(object):
 
     def _get_request(self, url, **kwargs):
         data = json.dumps(kwargs)
-        return requests.get(url, data=data, headers=self.headers).json()
+        json_data = requests.get(url, data=data, headers=self.headers).json()
+        return json_data
 
     def get_signal_data(self, productCodes, minTs, maxTs, lastOnly):
         return self._post_request(
@@ -600,7 +609,8 @@ class NaPoleonXConnector(object):
             Cleaned dataframe.
 
         """
-        data = pd.DataFrame(self.get_data(productCodes, minDate, maxDate))
+        json_data = self.get_data(productCodes, minDate, maxDate)
+        data = pd.DataFrame(json_data)
         df = self._set_dataframe(data, assets=productCodes, keep=keep)
         df.index = pd.to_datetime(df.index, format='%Y-%m-%d')
 
@@ -617,14 +627,14 @@ class NaPoleonXConnector(object):
     def get_signal_dataframe(self, productCodes, minDate, maxDate, last_only = True):
         minTs = dt.strptime(minDate, '%Y-%m-%d').strftime('%Y-%m-%d') + 'T00:00:00'
         maxTs = dt.strptime(maxDate, '%Y-%m-%d').strftime('%Y-%m-%d') + 'T23:59:59'
-        signals_df = pd.DataFrame(self.get_signal_data(productCodes,  minTs, maxTs, last_only))
+        signals_df = pd.DataFrame(self.get_signal_data(productCodes,  minTs, maxTs, last_only)['data'])
         return signals_df
 
     def get_underlyings(self, productCode):
-        data = self._get_request(self.url_product + productCode)
+        data = self._get_request(self.url_product + productCode)['data']
         return data['underlyings']
 
     def get_currency(self, productCode):
         data = self._get_request(self.url_product + productCode)
-        return data['currency']
+        return data['data']['currency']
 
