@@ -15,6 +15,13 @@ from sklearn.metrics import accuracy_score
 from functools import partial
 
 import hashlib
+from napoleontoolbox.utility import date_utility
+import pandas as pd
+import numpy as np
+
+from datetime import timedelta, date
+from numba import njit, jit, types, typed
+from numba.typed import Dict,List
 
 
 def get_readable_label(signal_parameters):
@@ -184,6 +191,19 @@ def f_sharpe_signals_mix(data, w, display_threshold = 0.99, period = 252):
         print(sharpe_strat)
     return -sharpe_strat
 
+
+@njit()
+def numba_expanding_zscore(signal_np_array, skipping_point):
+    me_zscore_expanding_array = np.zeros(signal_np_array.shape)
+    for i in range(len(signal_np_array)):
+        if i <= skipping_point:
+            me_zscore_expanding_array[i] = signal_np_array[i]
+        else :
+            std_dev = max(signal_np_array[:i].std(), 1e-6)
+            me_zscore_expanding_array[i] = (signal_np_array[i] - signal_np_array[:i].mean())/std_dev
+    return me_zscore_expanding_array
+
+
 def expanding_zscore(signal_np_array=None, skipping_point = 5, signal_continuum_threshold = 10):
     u = np.unique(signal_np_array)
     nb_distinct_signals = len(u)
