@@ -712,7 +712,7 @@ def fetch_all_necessary_data_b40(public_key = None, private_key= None, start_tim
         if row['Security Code'] == 'BTCUSDT':
             return 'BTC'
         elif row['Security Code'] == 'ETHUSDT':
-            return 'ETH'
+            return 'Ethereum'
         else:
             return np.nan
 
@@ -721,6 +721,21 @@ def fetch_all_necessary_data_b40(public_key = None, private_key= None, start_tim
     trades_df = trades_df[trades_columns]
     trades_df['Security Code'] = trades_df.apply(convert_symbol, axis=1)
 
+    def convert_side(row):
+        if row['Oper'] == 'SELL':
+            return 'SEL'
+        elif row['Oper'] == 'BUY':
+            return 'BUY'
+        else:
+            return np.nan
+    trades_df['Oper'] = trades_df.apply(convert_side, axis=1)
+
+    trades_df['Price']=trades_df['Price'].astype(float)
+    trades_df['Amount']=trades_df['Amount'].astype(float)
+
+
+    first_summary_df = trades_df.groupby(['Security Code', 'Oper'])['Amount'].sum()
+
     futures_income_history_df = walletHist[
         walletHist['incomeType'] == 'FUNDING_FEE'].copy()
     futures_income_history_df['Nature'] = 'CRY'
@@ -764,10 +779,6 @@ def fetch_all_necessary_data_b40(public_key = None, private_key= None, start_tim
     minDate = min(converted_history_balance.index)
     maxDate = max(converted_history_balance.index)
 
-    filtered_binance_df = binance_df[binance_df['Date'] >= minDate].copy()
-    filtered_binance_df = filtered_binance_df[filtered_binance_df['Date'] <= maxDate].copy()
-    funding_df = funding_df[funding_df['Date'] <= maxDate].copy()
-
     def filter_me_month(data_df, filtering_month):
         data_df['month'] = data_df['Date'].dt.month
         data_df['insideMonth'] = data_df['month'] == filtering_month
@@ -776,7 +787,7 @@ def fetch_all_necessary_data_b40(public_key = None, private_key= None, start_tim
         return data_df
 
     if not by_pass_month:
-        filtered_binance_df=filter_me_month(filtered_binance_df.copy(),me_month)
+        filtered_binance_df=filter_me_month(binance_df.copy(),me_month)
         funding_df=filter_me_month(funding_df.copy(),me_month)
 
     filteredWallet = filteredWallet.rename(columns = {
@@ -813,32 +824,39 @@ def fetch_all_necessary_data_b40(public_key = None, private_key= None, start_tim
 
     finalFilteredWallet = pd.merge(finalFilteredWallet, ohlc_usdt_day_cc, how='left', left_index=True, right_index=True)
     final_converted_history_balance = pd.merge(final_converted_history_balance, ohlc_usdt_day_cc, how='left', left_index=True, right_index=True)
-    finalFilteredWallet['Date'] = finalFilteredWallet['Date'].dt.strftime('%m/%d/%Y')
-    final_converted_history_balance['Date'] = final_converted_history_balance['Date'].dt.strftime('%m/%d/%Y')
+    finalFilteredWallet['Date'] = finalFilteredWallet['Date'].dt.strftime('%d/%m/%Y')
+    final_converted_history_balance['Date'] = final_converted_history_balance['Date'].dt.strftime('%d/%m/%Y')
 
-    filtered_binance_df['Date'] = filtered_binance_df['Date'].dt.strftime('%m/%d/%Y')
+    filtered_binance_df['Date'] = filtered_binance_df['Date'].dt.strftime('%d/%m/%Y')
 
     filtered_binance_df['Value'] = filtered_binance_df['Date']
     filtered_binance_df['Settlement'] = filtered_binance_df['Date']
 
-    filtered_binance_df['Depo'] = 'Binance'
-    filtered_binance_df['Bank'] = 'Binance'
+    filtered_binance_df['Depo'] = 'BIN'
+    filtered_binance_df['Bank'] = 'BIN'
 
-    filtered_binance_df['Pmt Cur'] = 'USDT'
+    filtered_binance_df['Pmt Cur'] = 'UST'
     filtered_binance_df['Source'] = 'Manual'
 
-    funding_df['Date'] = funding_df['Date'].dt.strftime('%m/%d/%Y')
+    filtered_binance_df['Currency'] = 'UST'
+
+    funding_df['Date'] = funding_df['Date'].dt.strftime('%d/%m/%Y')
 
     funding_df['Value'] = funding_df['Date']
     funding_df['Settlement'] = funding_df['Date']
 
-    funding_df['Depo'] = 'Binance'
-    funding_df['Bank'] = 'Binance'
+    funding_df['Depo'] = 'BIN'
+    funding_df['Bank'] = 'BIN'
 
-    funding_df['Pmt Cur'] = 'USDT'
+    funding_df['Pmt Cur'] = 'UST'
     funding_df['Source'] = 'Manual'
 
-    return filtered_binance_df, finalFilteredWallet, final_converted_history_balance, actualPositions, funding_df
+    funding_df['Currency'] = 'UST'
+
+
+    summary_df = filtered_binance_df.groupby(['Security Code', 'Oper'])['Amount'].sum()
+    summary_df = summary_df.reset_index()
+    return filtered_binance_df, finalFilteredWallet, final_converted_history_balance, actualPositions, funding_df, summary_df
 
 
 
