@@ -755,7 +755,7 @@ def fetch_all_necessary_data_b40(public_key = None, private_key= None, start_tim
     ##########
     ##############################
     ##############################
-    reprocess_numba_trades = False
+    reprocess_numba_trades = True
     if reprocess_numba_trades:
         trades = trades.sort_values(by='timestamp', ascending=True).drop_duplicates()
         # trades.transactTime = trades.transactTime.apply(lambda x: x.timestamp() * 1000)
@@ -834,10 +834,10 @@ def fetch_all_necessary_data_b40(public_key = None, private_key= None, start_tim
     bitmex_df = bitmex_df[bitmex_df['Nature'] == 'Trade'].copy()
 
     bitmex_df['Nature'] = 'CRY'
-    bitmex_df['Currency'] = 'USDT'
+    bitmex_df['Currency'] = 'UST'
 
     funding_df['Nature'] = 'CRY'
-    funding_df['Currency'] = 'USDT'
+    funding_df['Currency'] = 'UST'
 
     trades_columns = ['Nature', 'Security Code', 'Currency', 'Oper', 'Date', 'Amount','Price', 'Fees']
 
@@ -849,19 +849,13 @@ def fetch_all_necessary_data_b40(public_key = None, private_key= None, start_tim
         if row['Security Code'] == 'XBTUSD':
             return 'BTC'
         elif row['Security Code'] == 'ETHUSD':
-            return 'ETH'
+            return 'Ethereum'
         else:
             return np.nan
 
     bitmex_df['Security Code'] = bitmex_df.apply(convert_symbol, axis=1)
 
 
-
-    if not by_pass_month:
-        bitmex_df['month'] = bitmex_df['Date'].dt.month
-        bitmex_df = bitmex_df[bitmex_df['month'] == me_month].copy()
-        bitmex_df = bitmex_df.drop(columns=['month'])
-
     def filter_me_month(data_df, filtering_month):
         data_df['month'] = data_df['Date'].dt.month
         data_df['insideMonth'] = data_df['month'] == filtering_month
@@ -952,7 +946,7 @@ def fetch_all_necessary_data_b40(public_key = None, private_key= None, start_tim
     filWal = filWal.sort_values(by=['Date'])
     wal = wal.sort_values(by=['Date'])
 
-    filtered_bitmex_df['Date'] = filtered_bitmex_df['Date'].dt.strftime('%m/%d/%Y')
+    filtered_bitmex_df['Date'] = filtered_bitmex_df['Date'].dt.strftime('%d/%m/%Y')
 
     filtered_bitmex_df['Value'] = filtered_bitmex_df['Date']
     filtered_bitmex_df['Settlement'] = filtered_bitmex_df['Date']
@@ -960,10 +954,10 @@ def fetch_all_necessary_data_b40(public_key = None, private_key= None, start_tim
     filtered_bitmex_df['Depo'] = 'Bitmex'
     filtered_bitmex_df['Bank'] = 'Bitmex'
 
-    filtered_bitmex_df['Pmt Cur'] = 'USDT'
+    filtered_bitmex_df['Pmt Cur'] = 'UST'
     filtered_bitmex_df['Source'] = 'Manual'
 
-    funding_df['Date'] = funding_df['Date'].dt.strftime('%m/%d/%Y')
+    funding_df['Date'] = funding_df['Date'].dt.strftime('%d/%m/%Y')
 
     funding_df['Value'] = funding_df['Date']
     funding_df['Settlement'] = funding_df['Date']
@@ -971,10 +965,24 @@ def fetch_all_necessary_data_b40(public_key = None, private_key= None, start_tim
     funding_df['Depo'] = 'Bitmex'
     funding_df['Bank'] = 'Bitmex'
 
-    funding_df['Pmt Cur'] = 'USDT'
+    funding_df['Pmt Cur'] = 'UST'
     funding_df['Source'] = 'Manual'
 
-    return filtered_bitmex_df,filWal,wal,actual_positions, funding_df
+    def convert_side(row):
+        if row['Oper'] == 'Sell':
+            return 'SEL'
+        elif row['Oper'] == 'Buy':
+            return 'BUY'
+        else:
+            return np.nan
+
+    filtered_bitmex_df['Oper'] = filtered_bitmex_df.apply(convert_side, axis=1)
+
+    summary_df = filtered_bitmex_df.groupby(['Security Code', 'Oper'])['Amount'].sum()
+
+    summary_df = summary_df.reset_index()
+
+    return filtered_bitmex_df,filWal,wal,actual_positions, funding_df, summary_df
 
 
 def fetch_all_necessary_data_granular(public_key = None, private_key= None, start_time= None, end_time= None, me_month=None, save_to_dropbox = False, dropbox_token = None, local_root_directory ='./', recompute_all = True, by_pass_month = False):
